EntryStreamWriter

Struct EntryStreamWriter 

pub struct EntryStreamWriter<'b, W: AsyncWrite + Unpin> { /* private fields */ }
An entry writer which supports the streaming of data (ie. the writing of unknown size or data at runtime).

Note

Implementations

Source

impl<'b, W: AsyncWrite + Unpin> EntryStreamWriter<'b, W>

pub async fn close(self) -> Result<()>

Consumes this entry writer and completes all closing tasks.

This includes:

  • Finalising the CRC32 hash value for the written data.
  • Calculating the compressed and uncompressed byte sizes.
  • Constructing a central directory header.
  • Pushing that central directory header to the ZipFileWriter’s store.

Failure to call this function before going out of scope would result in a corrupted ZIP file.